@@ -31,12 +31,12 @@
 #include <glib/gi18n.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 #include <gconf/gconf-client.h>
 
 #define SN_API_NOT_YET_FROZEN
 #include <libsn/sn.h>
 #include <gdk/gdk.h>
+#include <gdk/gdkkeysyms.h>
 
 #include <totem-pl-parser.h>
 
@@ -48,7 +48,9 @@
 #include "bacon-video-widget.h"
 #include "totem-interface.h"
 #include "totem-statusbar.h"
-#include "bacon-volume.h"
+#include "totem-time-label.h"
+#include "totem-fullscreen.h"
+#include "totem-glow-button.h"
 #include "video-utils.h"
 
 #include "totem-plugin-viewer-commands.h"
@@ -57,9 +59,10 @@
 
 GtkWidget *totem_statusbar_create (void);
 GtkWidget *totem_volume_create (void);
+GtkWidget *totem_pp_create (void);
 
-#define VOLUME_DOWN_OFFSET -8
-#define VOLUME_UP_OFFSET 8
+#define VOLUME_DOWN_OFFSET (-0.08)
+#define VOLUME_UP_OFFSET (0.08)
 
 /* For newer D-Bus version */
 #ifndef DBUS_NAME_FLAG_PROHIBIT_REPLACEMENT
@@ -95,8 +98,10 @@ typedef struct _TotemEmbedded {
 	GObject parent;
 
 	GtkWidget *window;
-	GladeXML *menuxml, *xml;
+	GtkBuilder *menuxml, *xml;
 	GtkWidget *about;
+	GtkWidget *pp_button;
+	GtkWidget *pp_fs_button;
 	TotemStatusbar *statusbar;
 	int width, height;
 	const char *mimetype;
@@ -122,6 +127,13 @@ typedef struct _TotemEmbedded {
 	GtkAdjustment *seekadj;
 	GtkWidget *seek;
 
+	/* Volume */
+	GtkWidget *volume;
+
+	/* Fullscreen */
+	TotemFullscreen *fs;
+	GtkWidget * fs_window;
+
 	/* Error */
 
 	guint type : 3; /* TotemPluginType */
@@ -133,7 +145,6 @@ typedef struct _TotemEmbedded {
 	guint hidden : 1;
 	guint repeat : 1;
 	guint seeking : 1;
-	guint noautostart : 1;
 	guint autostart : 1;
 	guint audioonly : 1;
 } TotemEmbedded;
@@ -164,6 +175,12 @@ static void totem_embedded_clear_playlist (TotemEmbedded *embedded);
 
 static void totem_embedded_update_menu (TotemEmbedded *emb);
 static void on_open1_activate (GtkButton *button, TotemEmbedded *emb);
+static void totem_embedded_toggle_fullscreen (TotemEmbedded *emb);
+
+void on_about1_activate (GtkButton *button, TotemEmbedded *emb);
+void on_preferences1_activate (GtkButton *button, TotemEmbedded *emb);
+void on_copy_location1_activate (GtkButton *button, TotemEmbedded *emb);
+void on_fullscreen1_activate (GtkMenuItem *menuitem, TotemEmbedded *emb);
 
 enum {
 	BUTTON_PRESS,
@@ -185,6 +202,8 @@ totem_embedded_finalize (GObject *object)
 		g_object_unref (embedded->xml);
 	if (embedded->menuxml)
 		g_object_unref (embedded->menuxml);
+	if (embedded->fs)
+		g_object_unref (embedded->fs);
 
 	/* FIXME etc */
 
@@ -256,7 +275,7 @@ static void
 totem_embedded_set_state (TotemEmbedded *emb, TotemStates state)
 {
 	GtkWidget *image;
-	char id[32];
+	gchar *id;
 	static const char *states[] = {
 		"PLAYING",
 		"PAUSED",
@@ -269,14 +288,15 @@ totem_embedded_set_state (TotemEmbedded *emb, TotemStates state)
 
 	g_message ("Viewer state: %s", states[state]);
 
-	image = glade_xml_get_widget (emb->xml, "emb_pp_button_image");
+	image = gtk_button_get_image (GTK_BUTTON (emb->pp_button));
 
 	switch (state) {
 	case STATE_STOPPED:
-		g_snprintf (id, sizeof (id), "gtk-media-play-%s",
-			    gtk_widget_get_direction (image) ? "ltr" : "rtl");
+		id = GTK_STOCK_MEDIA_PLAY;
 		totem_statusbar_set_text (emb->statusbar, _("Stopped"));
 		totem_statusbar_set_time_and_length (emb->statusbar, 0, 0);
+		totem_time_label_set_time 
+			(TOTEM_TIME_LABEL (emb->fs->time_label), 0, 0);
 		if (emb->href_uri != NULL && emb->hidden == FALSE) {
 			gdk_window_set_cursor
 				(GTK_WIDGET (emb->bvw)->window,
@@ -284,12 +304,11 @@ totem_embedded_set_state (TotemEmbedded *emb, TotemStates state)
 		}
 		break;
 	case STATE_PAUSED:
-		g_snprintf (id, sizeof (id), "gtk-media-play-%s",
-				gtk_widget_get_direction (image) ? "ltr" : "rtl");
+		id = GTK_STOCK_MEDIA_PLAY;
 		totem_statusbar_set_text (emb->statusbar, _("Paused"));
 		break;
 	case STATE_PLAYING:
-		g_snprintf (id, sizeof (id), "gtk-media-pause");
+		id = GTK_STOCK_MEDIA_PAUSE;
 		totem_statusbar_set_text (emb->statusbar, _("Playing"));
 		if (emb->href_uri == NULL && emb->hidden == FALSE) {
 			gdk_window_set_cursor
@@ -298,10 +317,13 @@ totem_embedded_set_state (TotemEmbedded *emb, TotemStates state)
 		}
 		break;
 	default:
+		g_assert_not_reached ();
 		break;
 	}
 
-	gtk_image_set_from_icon_name (GTK_IMAGE (image), id, GTK_ICON_SIZE_MENU);
+	gtk_image_set_from_stock (GTK_IMAGE (image), id, GTK_ICON_SIZE_MENU);
+	gtk_tool_button_set_stock_id (GTK_TOOL_BUTTON (emb->pp_fs_button), id);
+
 	emb->state = state;
 }
 
@@ -369,10 +391,8 @@ totem_embedded_set_logo_by_name (TotemEmbedded *embedded,
 static void
 totem_embedded_set_pp_state (TotemEmbedded *emb, gboolean state)
 {
-	GtkWidget *item;
-
-	item = glade_xml_get_widget (emb->xml, "pp_button");
-	gtk_widget_set_sensitive (item, state);
+	gtk_widget_set_sensitive (emb->pp_button, state);
+	gtk_widget_set_sensitive (emb->pp_fs_button, state);
 }
 
 static gboolean
@@ -440,6 +460,10 @@ totem_embedded_open_internal (TotemEmbedded *emb,
 	}
 
 	totem_embedded_update_menu (emb);
+	if (emb->href_uri != NULL)
+		totem_fullscreen_set_title (emb->fs, emb->href_uri);
+	else
+		totem_fullscreen_set_title (emb->fs, emb->current_uri);
 
 	return retval;
 }
@@ -1007,7 +1031,8 @@ totem_embedded_set_playlist (TotemEmbedded *emb,
 static void
 totem_embedded_update_menu (TotemEmbedded *emb)
 {
-	GtkWidget *menu, *item, *image;
+	GtkWidget *item, *image;
+	GtkMenuShell *menu;
 	char *label;
 
 	if (emb->menu_item != NULL) {
@@ -1043,7 +1068,7 @@ totem_embedded_update_menu (TotemEmbedded *emb)
 	/* translators: this is:
 	 * Open With ApplicationName
 	 * as in nautilus' right-click menu */
-	label = g_strdup_printf ("_Open with \"%s\"", emb->app->name);
+	label = g_strdup_printf (_("_Open with \"%s\""), emb->app->name);
 	item = gtk_image_menu_item_new_with_mnemonic (label);
 	g_free (label);
 	image = gtk_image_new_from_stock (GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU);
@@ -1053,8 +1078,8 @@ totem_embedded_update_menu (TotemEmbedded *emb)
 	gtk_widget_show (item);
 	emb->menu_item = item;
 
-	menu = glade_xml_get_widget (emb->menuxml, "menu");
-	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), item);
+	menu = GTK_MENU_SHELL (gtk_builder_get_object (emb->menuxml, "menu"));
+	gtk_menu_shell_prepend (menu, item);
 }
 
 static void
@@ -1066,7 +1091,14 @@ on_open1_activate (GtkButton *button, TotemEmbedded *emb)
 	totem_embedded_stop (emb, NULL);
 }
 
-static void
+void
+on_fullscreen1_activate (GtkMenuItem *menuitem, TotemEmbedded *emb)
+{
+	if (totem_fullscreen_is_fullscreen (emb->fs) == FALSE)
+		totem_embedded_toggle_fullscreen (emb);
+}
+
+void
 on_about1_activate (GtkButton *button, TotemEmbedded *emb)
 {
 	char *backend_version, *description, *license;
@@ -1120,7 +1152,7 @@ on_about1_activate (GtkButton *button, TotemEmbedded *emb)
 	gtk_widget_show (emb->about);
 }
 
-static void
+void
 on_copy_location1_activate (GtkButton *button, TotemEmbedded *emb)
 {
 	GdkDisplay *display;
@@ -1145,12 +1177,20 @@ on_copy_location1_activate (GtkButton *button, TotemEmbedded *emb)
 	gtk_clipboard_set_text (clip, uri, -1);
 }
 
+void
+on_preferences1_activate (GtkButton *button, TotemEmbedded *emb)
+{
+	/* TODO: */
+}
+
 static void
 on_play_pause (GtkWidget *widget, TotemEmbedded *emb)
 {
 	if (emb->state == STATE_PLAYING) {
 		totem_embedded_pause (emb, NULL);
 	} else {
+		totem_glow_button_set_glow (TOTEM_GLOW_BUTTON (emb->pp_button), FALSE);
+
 		if (emb->current_uri == NULL) {
 			g_signal_emit (emb, signals[BUTTON_PRESS], 0,
 				       GDK_CURRENT_TIME, 0);
@@ -1192,6 +1232,41 @@ on_got_redirect (GtkWidget *bvw, const char *mrl, TotemEmbedded *emb)
 		totem_embedded_play (emb, NULL);
 }
 
+static void
+totem_embedded_toggle_fullscreen (TotemEmbedded *emb)
+{
+	GtkAction * fs_action = GTK_ACTION (gtk_builder_get_object 
+					    (emb->menuxml, "fullscreen1"));
+
+	if (totem_fullscreen_is_fullscreen (emb->fs) != FALSE)
+	{
+		GtkWidget * container;
+		container = GTK_WIDGET (gtk_builder_get_object (emb->xml,
+								"video_box"));
+
+		totem_fullscreen_set_fullscreen (emb->fs, FALSE);
+		gtk_widget_reparent (GTK_WIDGET (emb->bvw), container);
+		gtk_widget_hide_all (emb->fs_window);
+		
+		gtk_action_set_sensitive (fs_action, TRUE);
+	} else {
+		gtk_widget_reparent (GTK_WIDGET (emb->bvw), emb->fs_window);
+		bacon_video_widget_set_fullscreen (emb->bvw, TRUE);
+		gtk_window_fullscreen (GTK_WINDOW (emb->fs_window));
+		totem_fullscreen_set_fullscreen (emb->fs, TRUE);
+		gtk_widget_show_all (emb->fs_window);
+
+		gtk_action_set_sensitive (fs_action, FALSE);
+	}
+}
+
+static void
+totem_embedded_on_fullscreen_exit (GtkWidget *widget, TotemEmbedded *emb)
+{
+	if (totem_fullscreen_is_fullscreen (emb->fs) != FALSE)
+		totem_embedded_toggle_fullscreen (emb);
+}
+
 static gboolean
 on_video_button_press_event (BaconVideoWidget *bvw,
 			     GdkEventButton *event,
@@ -1216,7 +1291,7 @@ on_video_button_press_event (BaconVideoWidget *bvw,
 		   state == 0) {
 		GtkMenu *menu;
 
-		menu = GTK_MENU (glade_xml_get_widget (emb->menuxml, "menu"));
+		menu = GTK_MENU (gtk_builder_get_object (emb->menuxml, "menu"));
 		gtk_menu_popup (menu, NULL, NULL, NULL, NULL,
 				event->button, event->time);
 
@@ -1284,35 +1359,9 @@ on_error_event (BaconVideoWidget *bvw,
 }
 
 static void
-cb_vol (GtkWidget *val, TotemEmbedded *emb)
+cb_vol (GtkWidget *val, gdouble value, TotemEmbedded *emb)
 {
-	bacon_video_widget_set_volume (emb->bvw,
-		bacon_volume_button_get_value (BACON_VOLUME_BUTTON (val)));
-}
-
-static gboolean
-on_volume_scroll_event (GtkWidget *win, GdkEventScroll *event, TotemEmbedded *emb)
-{
-	GtkWidget *vbut;
-	int vol, offset;
-
-	switch (event->direction) {
-	case GDK_SCROLL_UP:
-		offset = VOLUME_UP_OFFSET;
-		break;
-	case GDK_SCROLL_DOWN:
-		offset = VOLUME_DOWN_OFFSET;
-		break;
-	default:
-		return FALSE;
-	}
-
-	vbut = glade_xml_get_widget (emb->xml, "volume_button");
-	vol = bacon_volume_button_get_value (BACON_VOLUME_BUTTON (vbut));
-	bacon_volume_button_set_value (BACON_VOLUME_BUTTON (vbut),
-			vol + offset);
-
-	return FALSE;
+	bacon_video_widget_set_volume (emb->bvw, value);
 }
 
 static void
@@ -1325,6 +1374,7 @@ on_tick (GtkWidget *bvw,
 {
 	if (emb->state != STATE_STOPPED) {
 		gtk_widget_set_sensitive (emb->seek, seekable);
+		gtk_widget_set_sensitive (emb->fs->seek, seekable);
 		if (emb->seeking == FALSE)
 			gtk_adjustment_set_value (emb->seekadj,
 					current_position * 65535);
@@ -1336,13 +1386,32 @@ on_tick (GtkWidget *bvw,
 					(int) (current_time / 1000),
 					(int) (stream_length / 1000));
 		}
+
+		totem_time_label_set_time 
+			(TOTEM_TIME_LABEL (emb->fs->time_label),
+			 current_time, stream_length);
 	}
 }
 
+static void
+property_notify_cb_volume (BaconVideoWidget *bvw, GParamSpec *spec,
+			   TotemEmbedded *emb)
+{
+	double volume;
+	
+	volume = bacon_video_widget_get_volume (emb->bvw);
+	
+	g_signal_handlers_block_by_func (emb->volume, cb_vol, emb);
+	gtk_scale_button_set_value (GTK_SCALE_BUTTON (emb->volume), volume);
+	g_signal_handlers_unblock_by_func (emb->volume, cb_vol, emb);
+}
+
 static gboolean
 on_seek_start (GtkWidget *widget, GdkEventButton *event, TotemEmbedded *emb)
 {
 	emb->seeking = TRUE;
+	totem_time_label_set_seeking (TOTEM_TIME_LABEL (emb->fs->time_label),
+				      TRUE);
 
 	return FALSE;
 }
@@ -1352,6 +1421,8 @@ cb_on_seek (GtkWidget *widget, GdkEventButton *event, TotemEmbedded *emb)
 {
 	bacon_video_widget_seek (emb->bvw,
 		gtk_range_get_value (GTK_RANGE (widget)) / 65535, NULL);
+	totem_time_label_set_seeking (TOTEM_TIME_LABEL (emb->fs->time_label),
+				      FALSE);
 	emb->seeking = FALSE;
 
 	return FALSE;
@@ -1368,17 +1439,91 @@ controls_size_allocate_cb (GtkWidget *controls,
 }
 #endif
 
+static void
+totem_embedded_action_volume_relative (TotemEmbedded *emb, double off_pct)
+{
+	double vol;
+	
+	if (bacon_video_widget_can_set_volume (emb->bvw) == FALSE)
+		return;
+	
+	vol = bacon_video_widget_get_volume (emb->bvw);
+	bacon_video_widget_set_volume (emb->bvw, vol + off_pct);
+}
+
+static gboolean
+totem_embedded_handle_key_press (TotemEmbedded *emb, GdkEventKey *event)
+{
+	switch (event->keyval) {
+	case GDK_Escape:
+		if (totem_fullscreen_is_fullscreen (emb->fs) != FALSE)
+			totem_embedded_toggle_fullscreen (emb);
+		return TRUE;
+	case GDK_F11:
+	case GDK_f:
+	case GDK_F:
+		totem_embedded_toggle_fullscreen (emb);
+		return TRUE;
+	case GDK_space:
+		on_play_pause (NULL, emb);
+		return TRUE;
+	case GDK_Up:
+		totem_embedded_action_volume_relative (emb, VOLUME_UP_OFFSET);
+		return TRUE;
+	case GDK_Down:
+		totem_embedded_action_volume_relative (emb, VOLUME_DOWN_OFFSET);
+		return TRUE;
+	case GDK_Left:
+	case GDK_Right:
+		/* FIXME: */
+		break;
+	}
+
+	return FALSE;
+}
+
+static gboolean
+totem_embedded_key_press_event (GtkWidget *widget, GdkEventKey *event,
+				TotemEmbedded *emb)
+{
+	if (event->type != GDK_KEY_PRESS)
+		return FALSE;
+	
+	if (event->state & GDK_CONTROL_MASK)
+	{
+		switch (event->keyval) {
+		case GDK_Left:
+		case GDK_Right:
+			return totem_embedded_handle_key_press (emb, event);
+		}
+	}
+
+	if (event->state & GDK_CONTROL_MASK ||
+	    event->state & GDK_MOD1_MASK ||
+	    event->state & GDK_MOD3_MASK ||
+	    event->state & GDK_MOD4_MASK ||
+	    event->state & GDK_MOD5_MASK)
+		return FALSE;
+
+	return totem_embedded_handle_key_press (emb, event);
+}
+
 static gboolean
 totem_embedded_construct (TotemEmbedded *emb,
 			  GdkNativeWindow xid,
 			  int width,
 			  int height)
 {
-	GtkWidget *child, *container, *pp_button, *vbut;
+	GtkWidget *child, *container, *image;
 	BvwUseType type;
 	GError *err = NULL;
 	GConfClient *gc;
-	int volume;
+	double volume;
+
+	emb->xml = totem_interface_load ("mozilla-viewer.ui", TRUE,
+					 GTK_WINDOW (emb->window), emb);
+	g_assert (emb->xml);
+
 
 	if (xid != 0) {
 		g_assert (!emb->hidden);
@@ -1388,22 +1533,12 @@ totem_embedded_construct (TotemEmbedded *emb,
 		/* Can't do anything before it's realized */
 		gtk_widget_realize (emb->window);
 
-		emb->xml = totem_interface_load_with_root ("mozilla-viewer.glade",
-				"content_box", _("Plugin") /* FIXME! */, TRUE,
-				GTK_WINDOW (emb->window));
-		g_assert (emb->xml);
-
-		child = glade_xml_get_widget (emb->xml, "content_box");
+		child = GTK_WIDGET (gtk_builder_get_object (emb->xml, "content_box"));
 		gtk_container_add (GTK_CONTAINER (emb->window), child);
 	} else {
 		g_assert (emb->hidden);
 
-		emb->xml = totem_interface_load_with_root ("mozilla-viewer.glade",
-				"window", _("Plugin") /* FIXME! */, TRUE,
-				GTK_WINDOW (emb->window));
-		g_assert (emb->xml);
-
-		emb->window = glade_xml_get_widget (emb->xml, "window");
+		emb->window = GTK_WIDGET (gtk_builder_get_object (emb->xml, "window"));
 	}
 
 	if (emb->hidden || emb->audioonly != FALSE)
@@ -1430,6 +1565,36 @@ totem_embedded_construct (TotemEmbedded *emb,
 			g_error_free (err);
 	}
 
+	/* Fullscreen setup */
+	emb->fs_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	gtk_widget_realize (emb->fs_window);
+	gtk_window_set_title (GTK_WINDOW (emb->fs_window), _("Totem Movie Player"));
+
+	emb->fs = totem_fullscreen_new (GTK_WINDOW (emb->fs_window));
+	totem_fullscreen_set_video_widget (emb->fs, emb->bvw);
+	g_signal_connect (G_OBJECT (emb->fs->exit_button), "clicked",
+			  G_CALLBACK (totem_embedded_on_fullscreen_exit), emb);
+
+	emb->pp_fs_button = GTK_WIDGET (gtk_tool_button_new_from_stock 
+					(GTK_STOCK_MEDIA_PLAY));
+	g_signal_connect (G_OBJECT (emb->pp_fs_button), "clicked",
+			  G_CALLBACK (on_play_pause), emb);
+	gtk_container_add (GTK_CONTAINER (emb->fs->buttons_box), emb->pp_fs_button);
+
+	/* Connect the keys */
+	gtk_widget_add_events (emb->fs_window, GDK_KEY_PRESS_MASK |
+			       GDK_KEY_RELEASE_MASK);
+	g_signal_connect (G_OBJECT(emb->fs_window), "key_press_event",
+			G_CALLBACK (totem_embedded_key_press_event), emb);
+	g_signal_connect (G_OBJECT(emb->fs_window), "key_release_event",
+			G_CALLBACK (totem_embedded_key_press_event), emb);
+	gtk_widget_add_events (GTK_WIDGET (emb->bvw), GDK_KEY_PRESS_MASK | 
+			       GDK_KEY_RELEASE_MASK);
+	g_signal_connect (G_OBJECT(emb->bvw), "key_press_event",
+			G_CALLBACK (totem_embedded_key_press_event), emb);
+	g_signal_connect (G_OBJECT(emb->bvw), "key_release_event",
+			G_CALLBACK (totem_embedded_key_press_event), emb);
+
 	g_signal_connect (G_OBJECT(emb->bvw), "got-redirect",
 			G_CALLBACK (on_got_redirect), emb);
 	g_signal_connect (G_OBJECT (emb->bvw), "eos",
@@ -1441,7 +1606,10 @@ totem_embedded_construct (TotemEmbedded *emb,
 	g_signal_connect (G_OBJECT(emb->bvw), "tick",
 			G_CALLBACK (on_tick), emb);
 
-	container = glade_xml_get_widget (emb->xml, "video_box");
+	g_signal_connect (G_OBJECT (emb->bvw), "notify::volume",
+			  G_CALLBACK (property_notify_cb_volume), emb);
+
+	container = GTK_WIDGET (gtk_builder_get_object (emb->xml, "video_box"));
 	if (type == BVW_USE_TYPE_VIDEO) {
 		gtk_container_add (GTK_CONTAINER (container), GTK_WIDGET (emb->bvw));
 		/* FIXME: why can't this wait until the whole window is realised? */
@@ -1452,47 +1620,55 @@ totem_embedded_construct (TotemEmbedded *emb,
 		gtk_widget_hide (container);
 	}
 
-	emb->seek = glade_xml_get_widget (emb->xml, "time_hscale");
+	emb->seek = GTK_WIDGET (gtk_builder_get_object (emb->xml, "time_hscale"));
 	emb->seekadj = gtk_range_get_adjustment (GTK_RANGE (emb->seek));
+	gtk_range_set_adjustment (GTK_RANGE (emb->fs->seek), emb->seekadj);
 	g_signal_connect (emb->seek, "button-press-event",
 			  G_CALLBACK (on_seek_start), emb);
 	g_signal_connect (emb->seek, "button-release-event",
 			  G_CALLBACK (cb_on_seek), emb);
+	g_signal_connect (emb->fs->seek, "button-press-event",
+			  G_CALLBACK (on_seek_start), emb);
+	g_signal_connect (emb->fs->seek, "button-release-event",
+			  G_CALLBACK (cb_on_seek), emb);
 
-	pp_button = glade_xml_get_widget (emb->xml, "pp_button");
-	g_signal_connect (G_OBJECT (pp_button), "clicked",
+	emb->pp_button = GTK_WIDGET (gtk_builder_get_object (emb->xml, "pp_button"));
+	image = gtk_image_new_from_stock (GTK_STOCK_MEDIA_PLAY, GTK_ICON_SIZE_MENU);
+	gtk_button_set_image (GTK_BUTTON (emb->pp_button), image);
+	g_signal_connect (G_OBJECT (emb->pp_button), "clicked",
 			  G_CALLBACK (on_play_pause), emb);
 
 	gc = gconf_client_get_default ();
-	volume = gconf_client_get_int (gc, GCONF_PREFIX"/volume", NULL);
+	volume = ((double) gconf_client_get_int (gc, GCONF_PREFIX"/volume", NULL)) / 100.0;
 	g_object_unref (G_OBJECT (gc));
 
-	bacon_video_widget_set_volume (emb->bvw, volume);
-	vbut = glade_xml_get_widget (emb->xml, "volume_button");
-	bacon_volume_button_set_value (BACON_VOLUME_BUTTON (vbut), volume);
-	g_signal_connect (G_OBJECT (vbut), "value-changed",
+	emb->volume = GTK_WIDGET (gtk_builder_get_object (emb->xml, "volume_button"));
+	gtk_scale_button_set_adjustment (GTK_SCALE_BUTTON (emb->fs->volume),
+					 gtk_scale_button_get_adjustment 
+					 (GTK_SCALE_BUTTON (emb->volume)));
+	gtk_button_set_focus_on_click (GTK_BUTTON (emb->volume), FALSE);
+	gtk_scale_button_set_value (GTK_SCALE_BUTTON (emb->volume), volume);
+	g_signal_connect (G_OBJECT (emb->volume), "value-changed",
 			  G_CALLBACK (cb_vol), emb);
-	gtk_widget_add_events (vbut, GDK_SCROLL_MASK);
-	g_signal_connect (G_OBJECT (vbut), "scroll_event",
-			G_CALLBACK (on_volume_scroll_event), emb);
+	bacon_video_widget_set_volume (emb->bvw, volume);
 
-	emb->statusbar = TOTEM_STATUSBAR (glade_xml_get_widget (emb->xml, "statusbar"));
+	emb->statusbar = TOTEM_STATUSBAR (gtk_builder_get_object (emb->xml, "statusbar"));
+	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (emb->statusbar), FALSE);
 
 	gtk_widget_set_size_request (emb->window, width, height);
 
 #ifdef GNOME_ENABLE_DEBUG
-	child = glade_xml_get_widget (emb->xml, "controls");
-	g_signal_connect_after (child, "size-allocate", G_CALLBACK (controls_size_allocate_cb), NULL);
+	child = GTK_WIDGET (gtk_builder_get_object (emb->xml, "controls"));
+	g_signal_connect_after (G_OBJECT (child), "size-allocate", G_CALLBACK (controls_size_allocate_cb), NULL);
 #endif
 
 	if (emb->controller_hidden != FALSE) {
-		child = glade_xml_get_widget (emb->xml, "controls");
+		child = GTK_WIDGET (gtk_builder_get_object (emb->xml, "controls"));
 		gtk_widget_hide (child);
 	}
 
 	if (!emb->show_statusbar) {
-		child = glade_xml_get_widget (emb->xml, "statusbar");
-		gtk_widget_hide (child);
+		gtk_widget_hide (GTK_WIDGET (emb->statusbar));
 	}
 
 	/* Try to make controls smaller */
@@ -1502,14 +1678,12 @@ totem_embedded_construct (TotemEmbedded *emb,
 		rcstyle = gtk_rc_style_new ();
 		rcstyle->xthickness = rcstyle->ythickness = 0;
 
-		child = glade_xml_get_widget (emb->xml, "pp_button");
-		gtk_widget_modify_style (child, rcstyle);
+		gtk_widget_modify_style (emb->pp_button, rcstyle);
 		
-		child = glade_xml_get_widget (emb->xml, "time_hscale");
+		child = GTK_WIDGET (gtk_builder_get_object (emb->xml, "time_hscale"));
 		gtk_widget_modify_style (child, rcstyle);
 
-		child = glade_xml_get_widget (emb->xml, "volume_button");
-		gtk_widget_modify_style (child, rcstyle);
+		gtk_widget_modify_style (emb->volume, rcstyle);
 
 		g_object_unref (rcstyle);
 	}
@@ -1521,20 +1695,10 @@ totem_embedded_construct (TotemEmbedded *emb,
 	}
 
 	/* popup */
-	emb->menuxml = totem_interface_load_with_root ("mozilla-viewer.glade",
-			"menu", _("Menu"), TRUE,
-			GTK_WINDOW (emb->window));
+	emb->menuxml = totem_interface_load ("mozilla-viewer.ui", TRUE,
+					     GTK_WINDOW (emb->window), emb);
 	g_assert (emb->menuxml);
 
-	child = glade_xml_get_widget (emb->menuxml, "about1");
-	g_signal_connect (G_OBJECT (child), "activate",
-			  G_CALLBACK (on_about1_activate), emb);
-	child = glade_xml_get_widget (emb->menuxml, "copy_location1");
-	g_signal_connect (G_OBJECT (child), "activate",
-			G_CALLBACK (on_copy_location1_activate), emb);
-	child = glade_xml_get_widget (emb->menuxml, "preferences1");
-	gtk_widget_hide (child);
-
 	/* Create cursor and set the logo */
 	if (!emb->hidden) {
 		emb->cursor = gdk_cursor_new_for_display
@@ -1543,6 +1707,9 @@ totem_embedded_construct (TotemEmbedded *emb,
 		totem_embedded_set_logo_by_name (emb, "totem");
 	}
 
+	if (!emb->hidden && emb->autostart == FALSE)
+		totem_glow_button_set_glow (TOTEM_GLOW_BUTTON (emb->pp_button), TRUE);
+
 	return TRUE;
 }
 
@@ -1736,31 +1903,6 @@ totem_embedded_push_parser (gpointer data)
 	return FALSE;
 }
 
-G_MODULE_EXPORT GtkWidget *
-totem_volume_create (void)
-{
-	GtkWidget *widget;
-
-	widget = bacon_volume_button_new (GTK_ICON_SIZE_MENU,
-					  0, 100, 1);
-	gtk_button_set_focus_on_click (GTK_BUTTON (widget), FALSE);
-	gtk_widget_show (widget);
-
-	return widget;
-}
-
-G_MODULE_EXPORT GtkWidget *
-totem_statusbar_create (void)
-{
-	GtkWidget *widget;
-
-	widget = totem_statusbar_new ();
-	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (widget), FALSE);
-	gtk_widget_show (widget);
-
-	return widget;
-}
-
 static char *arg_user_agent = NULL;
 static char *arg_mime_type = NULL;
 static char **arg_remaining = NULL;
