@@ -3,12 +3,14 @@
 #include <locale.h>
 
 #include <glib.h>
+#include <string.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <libgnomevfs/gnome-vfs.h>
 
 #include "totem-pl-parser.h"
 #include "totem-pl-parser-mini.h"
+#include "totem-pl-parser-private.h"
 
 #define USE_DATA
 
@@ -29,6 +31,8 @@ header (const char *message)
 	g_print ("\n");
 }
 
+#define error(x...) { g_warning (x); exit(1); }
+
 #if 0
 static void
 test_relative_real (const char *url, const char *output)
@@ -70,12 +74,47 @@ test_relative (void)
 			"/home/hadess/test/file.m3u");
 }
 #endif
+
 static void
-entry_added (TotemPlParser *parser, const char *uri, const char *title,
-		const char *genre, gpointer data)
+test_resolve_real (const char *base, const char *url, const char *expected)
 {
-	g_print ("added URI '%s' with title '%s' genre '%s'\n", uri,
-			title ? title : "empty", genre ? genre : "empty");
+	char *result;
+
+	result = totem_pl_resolve_url (base, url);
+	if (result == NULL)
+		error ("NULL output resolving '%s' with base '%s'", url, base);
+	if (strcmp (result, expected) != 0)
+		error ("Resolving '%s' with base '%s', different results than expected:\n'%s' instead of '%s'",
+		       url, base, result, expected);
+	g_print ("Resolved: '%s' with base '%s' to '%s'\n", url, base, result);
+	g_free (result);
+}
+
+static void
+test_resolve (void)
+{
+	header ("Resolve URL");
+
+	test_resolve_real ("http://localhost:12345/foobar", "/leopard.mov", "http://localhost:12345/leopard.mov");
+	test_resolve_real ("file:///home/hadess/Movies", "Movies/mymovie.mov", "file:///home/hadess/Movies/Movies/mymovie.mov");
+}
+
+static void
+entry_metadata_foreach (const char *key,
+			const char *value,
+			gpointer data)
+{
+	if (g_ascii_strcasecmp (key, "url") == 0)
+		return;
+	g_print ("\t%s = '%s'\n", key, value);
+}
+
+static void
+entry_parsed (TotemPlParser *parser, const char *uri,
+	      GHashTable *metadata, gpointer data)
+{
+	g_print ("added URI '%s'\n", uri);
+	g_hash_table_foreach (metadata, (GHFunc) entry_metadata_foreach, NULL);
 }
 
 static void
@@ -249,7 +288,7 @@ test_parsing (void)
 			  "force", option_force,
 			  "disable-unsafe", option_disable_unsafe,
 			  NULL);
-	g_signal_connect (G_OBJECT (pl), "entry", G_CALLBACK (entry_added), NULL);
+	g_signal_connect (G_OBJECT (pl), "entry-parsed", G_CALLBACK (entry_parsed), NULL);
 	g_signal_connect (G_OBJECT (pl), "playlist-start", G_CALLBACK (playlist_started), NULL);
 	g_signal_connect (G_OBJECT (pl), "playlist-end", G_CALLBACK (playlist_ended), NULL);
 
@@ -302,6 +341,7 @@ int main (int argc, char **argv)
 	}
 
 	if (files == NULL) {
+		test_resolve ();
 #if 0
 		test_relative ();
 #endif
