@@ -515,11 +515,11 @@ cd_cache_free (CdCache *cache)
   g_free (cache);
 }
 
-static MediaType
+static TotemDiscMediaType
 cd_cache_disc_is_cdda (CdCache *cache,
 		       GError **error)
 {
-  MediaType type;
+  TotemDiscMediaType type;
 
   /* We can't have audio CDs on disc, yet */
   if (cache->is_media == FALSE)
@@ -619,7 +619,7 @@ cd_cache_file_exists (CdCache *cache, const char *subdir, const char *filename)
   return ret;
 }
 
-static MediaType
+static TotemDiscMediaType
 cd_cache_disc_is_vcd (CdCache *cache,
                       GError **error)
 {
@@ -668,7 +668,7 @@ cd_cache_disc_is_vcd (CdCache *cache,
   return MEDIA_TYPE_DATA;
 }
 
-static MediaType
+static TotemDiscMediaType
 cd_cache_disc_is_dvd (CdCache *cache,
 		      GError **error)
 {
@@ -720,11 +720,30 @@ totem_cd_mrl_from_type (const char *scheme, const char *dir)
   return retval;
 }
 
-MediaType
+static char *
+totem_cd_dir_get_parent (const char *dir)
+{
+    GnomeVFSURI *uri, *parent_uri;
+    char *parent;
+
+    uri = gnome_vfs_uri_new (dir);
+    if (uri == NULL)
+      return NULL;
+    parent_uri = gnome_vfs_uri_get_parent (uri);
+    gnome_vfs_uri_unref (uri);
+    if (parent_uri == NULL)
+      return NULL;
+    parent = gnome_vfs_uri_to_string (parent_uri, GNOME_VFS_URI_HIDE_NONE);
+    gnome_vfs_uri_unref (parent_uri);
+
+    return parent;
+}
+
+TotemDiscMediaType
 totem_cd_detect_type_from_dir (const char *dir, char **url, GError **error)
 {
   CdCache *cache;
-  MediaType type;
+  TotemDiscMediaType type;
 
   g_return_val_if_fail (dir != NULL, MEDIA_TYPE_ERROR);
 
@@ -735,32 +754,49 @@ totem_cd_detect_type_from_dir (const char *dir, char **url, GError **error)
     return MEDIA_TYPE_ERROR;
   if ((type = cd_cache_disc_is_vcd (cache, error)) == MEDIA_TYPE_DATA &&
       (type = cd_cache_disc_is_dvd (cache, error)) == MEDIA_TYPE_DATA) {
-    /* crap, nothing found */
+    /* is it the directory itself? */
+    char *parent;
+
     cd_cache_free (cache);
-    return type;
+    parent = totem_cd_dir_get_parent (dir);
+    if (!parent)
+      return type;
+
+    cache = cd_cache_new (parent, error);
+    g_free (parent);
+    if (!cache)
+      return MEDIA_TYPE_ERROR;
+    if ((type = cd_cache_disc_is_vcd (cache, error)) == MEDIA_TYPE_DATA &&
+	(type = cd_cache_disc_is_dvd (cache, error)) == MEDIA_TYPE_DATA) {
+      /* crap, nothing found */
+      cd_cache_free (cache);
+      return type;
+    }
   }
-  cd_cache_free (cache);
 
   if (url == NULL) {
+    cd_cache_free (cache);
     return type;
   }
 
   if (type == MEDIA_TYPE_DVD) {
-    *url = totem_cd_mrl_from_type ("dvd", dir);
+    *url = totem_cd_mrl_from_type ("dvd", cache->mountpoint);
   } else if (type == MEDIA_TYPE_VCD) {
-    *url = totem_cd_mrl_from_type ("vcd", dir);
+    *url = totem_cd_mrl_from_type ("vcd", cache->mountpoint);
   }
 
+  cd_cache_free (cache);
+
   return type;
 }
 
-MediaType
+TotemDiscMediaType
 totem_cd_detect_type_with_url (const char *device,
     			       char      **url,
 			       GError     **error)
 {
   CdCache *cache;
-  MediaType type;
+  TotemDiscMediaType type;
 
   if (url != NULL)
     *url = NULL;
@@ -807,7 +843,7 @@ totem_cd_detect_type_with_url (const char *device,
   return type;
 }
 
-MediaType
+TotemDiscMediaType
 totem_cd_detect_type (const char  *device,
 		      GError     **error)
 {
@@ -830,7 +866,7 @@ totem_cd_has_medium (const char  *device)
 }
 
 const char *
-totem_cd_get_human_readable_name (MediaType type)
+totem_cd_get_human_readable_name (TotemDiscMediaType type)
 {
   switch (type)
   {
