@@ -36,6 +36,12 @@ G_BEGIN_DECLS
 #define TOTEM_IS_PLAYLIST(obj)         (GTK_CHECK_TYPE ((obj), TOTEM_TYPE_PLAYLIST))
 #define TOTEM_IS_PLAYLIST_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), TOTEM_TYPE_PLAYLIST))
 
+typedef enum {
+	TOTEM_PLAYLIST_STATUS_NONE,
+	TOTEM_PLAYLIST_STATUS_PLAYING,
+	TOTEM_PLAYLIST_STATUS_PAUSED
+} TotemPlaylistStatus;
+
 typedef enum {
 	TOTEM_PLAYLIST_DIRECTION_NEXT,
 	TOTEM_PLAYLIST_DIRECTION_PREVIOUS
@@ -87,6 +93,9 @@ void       totem_playlist_clear_with_gnome_vfs_volume (TotemPlaylist *playlist,
 char      *totem_playlist_get_current_mrl (TotemPlaylist *playlist);
 char      *totem_playlist_get_current_title (TotemPlaylist *playlist,
 					     gboolean *custom);
+char      *totem_playlist_get_title (TotemPlaylist *playlist,
+				     guint index);
+
 gboolean   totem_playlist_get_current_metadata (TotemPlaylist *playlist,
 						char         **artist,
 						char         **title,
@@ -110,7 +119,7 @@ gboolean   totem_playlist_get_shuffle (TotemPlaylist *playlist);
 void       totem_playlist_set_shuffle (TotemPlaylist *playlist,
 				       gboolean shuffle);
 
-gboolean   totem_playlist_set_playing (TotemPlaylist *playlist, gboolean state);
+gboolean   totem_playlist_set_playing (TotemPlaylist *playlist, TotemPlaylistStatus state);
 
 void       totem_playlist_set_at_start (TotemPlaylist *playlist);
 void       totem_playlist_set_at_end (TotemPlaylist *playlist);
