@@ -30,7 +30,6 @@
 
 #include <glib-object.h>
 #include <gtk/gtk.h>
-
 #include "plparse/totem-disc.h"
 
 #define TOTEM_GCONF_PREFIX "/apps/totem"
@@ -69,6 +68,21 @@ typedef enum {
 	TOTEM_REMOTE_COMMAND_MUTE
 } TotemRemoteCommand;
 
+typedef enum {
+	TOTEM_REMOTE_SETTING_SHUFFLE,
+	TOTEM_REMOTE_SETTING_REPEAT
+} TotemRemoteSetting;
+
+GType totem_remote_command_get_type	(void);
+GQuark totem_remote_command_quark	(void);
+#define TOTEM_TYPE_REMOTE_COMMAND	(totem_remote_command_get_type())
+#define TOTEM_REMOTE_COMMAND		totem_remote_command_quark ()
+
+GType totem_disc_media_type_get_type	(void);
+GQuark totem_disc_media_type_quark	(void);
+#define TOTEM_TYPE_DISC_MEDIA_TYPE	(totem_disc_media_type_get_type())
+#define TOTEM_DISC_MEDIA_TYPE		totem_disc_media_type_quark ()
+
 #define SHOW_PLAYING_NO_TRACKS "NONE"
 
 #define TOTEM_TYPE_OBJECT              (totem_object_get_type ())
@@ -113,7 +127,7 @@ void	totem_action_next			(Totem *totem);
 void	totem_action_previous			(Totem *totem);
 void	totem_action_seek_time			(Totem *totem, gint64 sec);
 void	totem_action_seek_relative		(Totem *totem, int off_sec);
-void	totem_action_volume_relative		(Totem *totem, int off_pct);
+void	totem_action_volume_relative		(Totem *totem, double off_pct);
 gboolean totem_action_set_mrl			(Totem *totem,
 						 const char *mrl);
 void	totem_action_set_mrl_and_play		(Totem *totem,
@@ -124,13 +138,14 @@ gboolean totem_action_set_mrl_with_warning	(Totem *totem,
 						 gboolean warn);
 
 void	totem_action_play_media			(Totem *totem,
-						 MediaType type,
+						 TotemDiscMediaType type,
 						 const char *device);
 
 void	totem_action_toggle_aspect_ratio	(Totem *totem);
 void	totem_action_set_aspect_ratio		(Totem *totem, int ratio);
 int	totem_action_get_aspect_ratio		(Totem *totem);
 void	totem_action_toggle_controls		(Totem *totem);
+void	totem_action_next_angle			(Totem *totem);
 
 void	totem_action_set_scale_ratio		(Totem *totem, gfloat ratio);
 void    totem_action_error                      (const char *title,
@@ -141,12 +156,20 @@ void    totem_action_play_media_device		(Totem *totem,
 
 gboolean totem_is_fullscreen			(Totem *totem);
 gboolean totem_is_playing			(Totem *totem);
+gboolean totem_is_paused			(Totem *totem);
 gboolean totem_is_seekable			(Totem *totem);
 GtkWindow *totem_get_main_window		(Totem *totem);
 GtkUIManager *totem_get_ui_manager		(Totem *totem);
 GtkWidget *totem_get_video_widget		(Totem *totem);
+char *	totem_get_short_title			(Totem *totem);
 
-gint64 totem_get_current_time			(Totem *totem);
+gint64	totem_get_current_time			(Totem *totem);
+guint	totem_get_playlist_length		(Totem *totem);
+void	totem_action_set_playlist_index		(Totem *totem,
+						 guint index);
+guint	totem_get_playlist_pos			(Totem *totem);
+char *	totem_get_title_at_playlist_pos		(Totem *totem,
+						 guint index);
 
 void    totem_add_sidebar_page			(Totem *totem,
 						 const char *page_id,
@@ -158,5 +181,10 @@ void    totem_remove_sidebar_page		(Totem *totem,
 void    totem_action_remote			(Totem *totem,
 						 TotemRemoteCommand cmd,
 						 const char *url);
+void	totem_action_remote_set_setting		(Totem *totem,
+						 TotemRemoteSetting setting,
+						 gboolean value);
+gboolean totem_action_remote_get_setting	(Totem *totem,
+						 TotemRemoteSetting setting);
 
 #endif /* __TOTEM_H__ */
